@@ -31,6 +31,11 @@ CONNECTORS_REGISTRY = {
         'label': 'Microsoft Azure SQL',
         'logo': 'azure_mssql/sql-azure.png',
     },
+    'Clickhouse': {
+        'connector': 'clickhouse.clickhouse_connector.ClickhouseConnector',
+        'label': 'Clickhouse',
+        'logo': 'clickhouse/clickhouse.png',
+    },
     'Dataiku': {
         'connector': 'dataiku.dataiku_connector.DataikuConnector',
         'logo': 'dataiku/dataiku.png',
@@ -117,6 +122,10 @@ CONNECTORS_REGISTRY = {
         'connector': 'lightspeed.lightspeed_connector.LightspeedConnector',
         'logo': 'lightspeed/lightspeed.png',
     },
+    'LinkedinAds': {
+        'connector': 'linkedinads.linkedinads_connector.LinkedinadsConnector',
+        'logo': 'linkedinads/linkedinads.png',
+    },
     'MicroStrategy': {
         'connector': 'micro_strategy.micro_strategy_connector.MicroStrategyConnector',
         'logo': 'micro_strategy/microstrategy.png',
